@@ -1,4 +1,3 @@
-from absl import logging
 from detextify.inpainter import Inpainter
 from detextify.text_detector import TextDetector
 
@@ -8,13 +7,19 @@ class Detextifier:
         self.text_detector = text_detector
         self.inpainter = inpainter
 
-    def detextify(self, in_image_path: str, out_image_path: str, max_retries=5):
+    def detextify(self, in_image_path: str, out_image_path: str, prompt=Inpainter.DEFAULT_PROMPT, max_retries=5):
         to_inpaint_path = in_image_path
         for i in range(max_retries):
-            logging.info(f"Inpainting iteration {i} for image {in_image_path}...")
+            print(f"Iteration {i} of {max_retries} for image {in_image_path}:")
+
+            print(f"\tCalling text detector...")
             text_boxes = self.text_detector.detect_text(to_inpaint_path)
-            logging.info(f"Detected {len(text_boxes)} text boxes.")
+            print(f"\tDetected {len(text_boxes)} text boxes.")
+
             if not text_boxes:
                 break
-            self.inpainter.inpaint(to_inpaint_path, text_boxes, out_image_path)
+
+            print(f"\tCalling in-painting model...")
+            self.inpainter.inpaint(to_inpaint_path, text_boxes, prompt, out_image_path)
             to_inpaint_path = out_image_path
+
